﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion


using System.Collections.Generic;
namespace HeuristicLab.Problems.Instances.Regression {
  public abstract class ArtificialRegressionDataDescriptor : IDataDescriptor {
    public abstract string Name { get; }
    public abstract string Description { get; }

    protected abstract string TargetVariable { get; }
    protected abstract IEnumerable<string> InputVariables { get; }
    protected abstract IEnumerable<string> AllowedInputVariables { get; }
    protected abstract int TrainingPartitionStart { get; }
    protected abstract int TrainingPartitionEnd { get; }
    protected abstract int TestPartitionStart { get; }
    protected abstract int TestPartitionEnd { get; }

    public RegressionData GenerateRegressionData() {
      RegressionData regData = new RegressionData();
      regData.Name = this.Name;
      regData.Description = this.Description;
      regData.InputVariables = this.InputVariables;
      regData.AllowedInputVariables = this.AllowedInputVariables;
      regData.TargetVariable = this.TargetVariable;
      regData.Values = this.GenerateValues();
      regData.TrainingPartitionStart = this.TrainingPartitionStart;
      regData.TrainingPartitionEnd = this.TrainingPartitionEnd;
      regData.TestPartitionStart = this.TestPartitionStart;
      regData.TestPartitionEnd = this.TestPartitionEnd;
      return regData;
    }

    protected abstract double[,] GenerateValues();
  }
}
